@@ -3,11 +3,11 @@ import os
 
 
 def matlab(index):
-    command1 = "cp ./InputFiles/dummy_model_" + str(index) + ".number_of_variables ."
+    command1 = "cp ./InputFiles/dummy_model_" + str(index) + ".m ."
     command2 = "/Applications/MATLAB_R2018a.app/bin/matlab " \
-               "-nosplash -nojvm -nodisplay -nodesktop -r 'run dummy_model_" + str(index) + ".number_of_variables; exit'"
+               "-nosplash -nojvm -nodisplay -nodesktop -r 'run dummy_model_" + str(index) + ".m; exit'"
     command3 = "mv ./OutputFiles/oupt.out ./OutputFiles/oupt_" + str(index) + ".out"
-    command4 = "rm dummy_model_" + str(index) + ".number_of_variables"
+    command4 = "rm dummy_model_" + str(index) + ".m"
     os.system(command1)
     os.system(command2)
     os.system(command3)
